@@ -1,3 +1,3 @@
-import colors from "../colors";
+import colors from "../colors.js";
 
 export default colors("1f77b4ff7f0e2ca02cd627289467bd8c564be377c27f7f7fbcbd2217becf");
